==> progamification-0.0.68.tar.gz: sample/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:progamification/progamification.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await GamificationService.init(
      '1f5c88ef-830c-47f7-8da0-b17b4e3fe536',
      'dbb74e4e-bf07-4a41-ab5c-f75696bc39dd',
      '641c3fdc266aea001186a0d6',
      '6411ca0e8803bd763670c096');
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      debugShowCheckedModeBanner: false,
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);
  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;

  Future<void> _incrementCounter() async {
    await GamificationService.updateGameAction(
        '642528cbc403460011d49189', '6411cacd8803bd485670c0c0', '', '');
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
        actions: [
          LeaderBoard('641c3fdc266aea001186a0d6', '6411ca0e8803bd763670c096')
        ],
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            const Text(
              'You have pushed the button this many times:',
            ),
            Text(
              '$_counter',
              style: Theme.of(context).textTheme.headline4,
            ),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        backgroundColor: Colors.red,
        child: const Icon(Icons.add),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}

==> progamification-0.0.81.tar.gz: sample/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:progamification/progamification.dart';

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  await GamificationService.init(
      '1f5c88ef-830c-47f7-8da0-b17b4e3fe536',
      'dbb74e4e-bf07-4a41-ab5c-f75696bc39dd',
      'usertesting61299',
      '6411ca0e8803bd763670c096');
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      debugShowCheckedModeBanner: false,
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);
  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  int _counter = 0;

  Future<void> _incrementCounter() async {
    await GamificationService.updateGameAction(
        'usertesting61299', '6411cacd8803bd485670c0c0', '', '');
    setState(() {
      _counter++;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(widget.title),
        actions: [LeaderBoard('usertesting61299', '6411ca0e8803bd763670c096')],
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            const Text(
              'You have pushed the button this many times:',
            ),
            Text(
              '$_counter',
              style: Theme.of(context).textTheme.headline4,
            ),
          ],
        ),
      ),
      floatingActionButton: FloatingActionButton(
        onPressed: _incrementCounter,
        tooltip: 'Increment',
        backgroundColor: Colors.red,
        child: const Icon(Icons.add),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}
